A Python library for using the Abenity API.

[API Documentation](https://abenity.com/developers/api/members)

*Ported from:* [https://github.com/Abenity/abenity-php](https://github.com/Abenity/abenity-php)

```bash
$ pip install abenity
```
